chicken_turtle_util.test
========================

.. automodule:: chicken_turtle_util.test

.. autosummary::
   :nosignatures:

   assert_text_contains
   assert_text_equals
   assert_matches
   assert_search_matches
   temp_dir_cwd

.. autofunction:: temp_dir_cwd
.. autofunction:: assert_text_contains
.. autofunction:: assert_text_equals
.. autofunction:: assert_matches
.. autofunction:: assert_search_matches
